ImgSimdIterPtrMut

Trait ImgSimdIterPtrMut 

pub trait ImgSimdIterPtrMut:
    SealedSimdPtrMut
    + ImgSimdIterPtr
    + ImgIterPtrMut {
    // Provided methods
    unsafe fn simd_iter_row_ptr_mut<const LANES: usize>(
        &self,
        row: usize,
    ) -> SimdIterPtrMut<Self::Item, LANES>  { ... }
    unsafe fn simd_iter_rows_ptr_mut<const LANES: usize>(
        &self,
    ) -> SimdIterWindowsPtrMut<Self::Item, LANES>  { ... }
    unsafe fn simd_iter_col_ptr_mut<const LANES: usize>(
        &self,
        col: usize,
    ) -> SimdIterPtrMut<Self::Item, LANES>  { ... }
    unsafe fn simd_iter_cols_ptr_mut<const LANES: usize>(
        &self,
    ) -> SimdIterWindowsPtrMut<Self::Item, LANES>  { ... }
}
Exposes iterators that return arrays of *mut pointers.

Implemented for mut buffer pointers, i.e. Img<*mut [T]>.

Provided Methods

unsafe fn simd_iter_row_ptr_mut<const LANES: usize>( &self, row: usize, ) -> SimdIterPtrMut<Self::Item, LANES>

Returns an iterator over pointers to the pixels of the specified row. row.

Safety

The caller must ensure that the pointer contained by the Img is valid for reads from all pixels of the specified row, and that the pointer remains valid for the lifetime of the iterator.

Panics

Panics if the specified row is out of bounds for the Img.

unsafe fn simd_iter_rows_ptr_mut<const LANES: usize>( &self, ) -> SimdIterWindowsPtrMut<Self::Item, LANES>

Returns an iterator over SimdIterWindowPtrMuts.

Safety

The caller must ensure that the pointer contained by the Img is valid for reads and writes for all pixels, and that the pointer remains valid for the lifetime of the iterator.

unsafe fn simd_iter_col_ptr_mut<const LANES: usize>( &self, col: usize, ) -> SimdIterPtrMut<Self::Item, LANES>

Returns an iterator over pointers to the pixels of the specified column.

Safety

The caller must ensure that the pointer contained by the Img is valid for reads from all pixels of the specified column, and that the pointer remains valid for the lifetime of the iterator.

Panics

Panics if the specified column is out of bounds for the Img.

unsafe fn simd_iter_cols_ptr_mut<const LANES: usize>( &self, ) -> SimdIterWindowsPtrMut<Self::Item, LANES>

Returns an iterator over SimdIterWindowPtrMuts.

Safety

The caller must ensure that the pointer contained by the Img is valid for reads and writes for all pixels, and that the pointer remains valid for the lifetime of the iterator.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T> ImgSimdIterPtrMut for Img<*mut [T]>

Available on crate features simd only.
Source

unsafe fn simd_iter_row_ptr_mut<const LANES: usize>( &self, row: usize, ) -> SimdIterPtrMut<Self::Item, LANES>

Source

unsafe fn simd_iter_rows_ptr_mut<const LANES: usize>( &self, ) -> SimdIterWindowsPtrMut<Self::Item, LANES>

Source

unsafe fn simd_iter_col_ptr_mut<const LANES: usize>( &self, col: usize, ) -> SimdIterPtrMut<Self::Item, LANES>

Source

unsafe fn simd_iter_cols_ptr_mut<const LANES: usize>( &self, ) -> SimdIterWindowsPtrMut<Self::Item, LANES>

Implementors